# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-Symbol-Util
Version:	0.0203
Release:	16.%{__distinit}%{__distvers}
Summary:	Additional utilities for Perl symbols manipulation
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Symbol-Util/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/Symbol-Util-%{version}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		Symbol-Util-0.0203-Critic.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	patch
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(Test::More) >= 0.88
# Release Tests
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), hunspell-en
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Carp)

%description
This module provides a set of additional functions useful for Perl symbols
manipulation.

%prep
%setup -q -n Symbol-Util-%{version}

# Clean up permissions where necessary
chmod -c -x,u+w examples/*

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
export GNUPGHOME=%{gnupghome}
RELEASE_TESTS="$(echo xt/*.t)"

# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"

# Don't run the spelling test yet as we need to work around a hunspell issue
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/pod_spell.t||')"

# Don't run the perlcritic test yet as we need to patch the code
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"

make test TEST_FILES="$RELEASE_TESTS"

# Patch the code to turn off one check before running the perlcritic test
patch -p0 < %{P:0}
make test TEST_FILES=xt/perlcritic.t
patch -p0 -R < %{P:0}

# Fix the POD Spell test to work around hunspell not recognising "doesn't" and run it
# (affects hunspell prior to Fedora 14/RHEL-6)
mv xt/pod_spellrc xt/pod_spellrc.orig
(
	cat xt/pod_spellrc.orig
	echo "doesn"
) > xt/pod_spellrc
make test TEST_FILES=xt/pod_spell.t
mv xt/pod_spellrc.orig xt/pod_spellrc

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes examples/ README
%{perl_vendorlib}/Symbol/
%{_mandir}/man3/Symbol::Util.3*

%changelog
* Thu Apr 12 2018 Paul Howarth <paul@city-fan.org> - 0.0203-16
- Use ephemeral directory for GNUPGHOME and simplify the build process
- Use gnupg2 rather than gnupg
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop workaround for building with Test::More < 0.88

* Tue Sep 27 2016 Paul Howarth <paul@city-fan.org> - 0.0203-12
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.0203-8
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.0203-5
- Perl 5.18 rebuild

* Sun Jun 23 2013 Paul Howarth <paul@city-fan.org> - 0.0203-3
- Tweak the perlcritic test, which has discovered something to moan about

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 0.0203-2
- BR: perl(Cwd), perl(File::Spec) and perl(Test::More)
- Specify version requirements for Test::Pod and Test::Pod::Coverage

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 0.0203-1
- Update to 0.0203
  - Compiles cleanly with Perl 5.14: defined(%%hash) and defined(@array) are
    deprecated (CPAN RT#75763)
  - Minor changes in POD
- BR:/R: perl(Carp)
- Sample documentation eg/ directory renamed to examples/
- Don't need to remove empty directories from buildroot
- Don't need to work around MYMETA.* generation
- Add workaround for some versions of hunspell not handling "doesn't" properly
- Drop compatibility with distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Never need to BR: aspell-en-gb
  - Test::Perl::Critic always available

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.0202-8
- Rebuild for perl 5.14.1 in Rawhide
- Work around signature test failing on recent distributions due to presence
  of MYMETA.yml
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.0202-7
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0202-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.0202-5
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue Jun 22 2010 Petr Pisar <ppisar@redhat.com> - 0.0202-4
- Rebuild against perl-5.12

* Tue May 04 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-3
- Remove perl from BuildRequires

* Mon May 03 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-2
- Add missing BuildRequires

* Mon Apr 12 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.0202-1
- Specfile autogenerated by cpanspec 1.78
